@@ -13,6 +13,7 @@ import numpy as np
 from hockey_rink import NHLRink, IIHFRink, NWHLRink
 import matplotlib.pyplot as plt
 import matplotlib.image as mpimg
+from matplotlib.legend_handler import HandlerPathCollection
 import os
 
 ############################################## Team colors dictionary ##############################################
@@ -340,13 +341,26 @@ def game_rink_map(data, good_team = None, title = None, size = None, strengths =
 
             if team == good_team:
 
-                ax.legend(loc="lower center", ncol=3, title = f'{team}', fontsize = 14,
-                            title_fontsize = 16, facecolor = 'white', framealpha = 1, edgecolor = 'gray').set_zorder(-1)
+                legend = ax.legend(loc="lower center", ncol=3, title = f'{team}', fontsize = 14,
+                                    title_fontsize = 16, facecolor = 'white', framealpha = 1, edgecolor = 'gray').set_zorder(-1)
+
+                if legend != None:
+
+                    for handle in legend.legendHandles:
+                        
+                        handle.set_sizes([250])
                 
             if team == bad_team:
 
-                ax.legend(loc="upper center", ncol=3, title = f'{team}', fontsize = 14,
-                            title_fontsize = 16, facecolor = 'white', framealpha = 1, edgecolor = 'gray').set_zorder(-1)
+                legend = ax.legend(loc="upper center", ncol=3, title = f'{team}', fontsize = 14,
+                                    title_fontsize = 16, facecolor = 'white', framealpha = 1, edgecolor = 'gray').set_zorder(-1)
+
+                if legend != None:
+
+                    for handle in legend.legendHandles:
+                        
+                        handle.set_sizes([250])
+
         if save_img == True:
             
             if os.path.exists('rink_plots') == False:
